# PLEASE NOTE:
# This code follows the coding outlines in our technical appendix. For more 
# information, please read the original paper and the technical appendix. Both
# can be found here: http://www.pnas.org/content/early/2018/10/18/1808793115

# This code is structured along the six dimensions of integration. For some 
# questions/dimensions the values assigned to answer options need no further
# recoding. For other questions, some recoding is neccessary. 

# This code will not compute integration scores for respondents that didn't 
# answer all questions. These cases will result in missing values. Depending
# on their specific project, researchers should use different strategies on how
# to deal with missing values. 
# This code was written by Niklas Harder


# Set your working directory. The directory should include one /code folder for
# code and one /data folder for data.

setwd("Your directory")

# Read data. This command was written to read data that was downloaded from 
# Qualtrics as a .csv file through the legacy export function. 

df <- read.csv("data/IPL24_simulatedData.csv", sep = ",", header = TRUE, skip = 1, encoding = "UTF-8", 
         stringsAsFactors = FALSE)

# Check if all recorded answers finished the survey
sum(df$Finished) == nrow(df)

# Load needed packages
require(scales)
require(reshape)


# Rename variables --------------------------------------------------------

# First rename some very long variable names
df <- reshape::rename(df,
                      c("polLr.The.Republican.Party.is.considered.to.be.left.of.the.Democratic.Party." =
                          "rightLeftOfLeft",
                        "polLr.The.Republican.Party.is.considered.to.be.right.of.the.Democratic.Party." =
                          "rightRightOfRight",
                        "polBehavior....tried.to.influence.others.on.how.to.vote." =
                          "influenceVote",
                        "polBehavior....made.a.political.statement.in.a.public.setting.or.online.regarding.politics.in.the.United.States." =
                          "publicStatement",
                        "polBehavior....engaged.in.public.or.online.discussions.regarding.politics.in.the.United.States." =
                          "publicDiscussion",
                        "polBehavior....tried.to.convince.somebody.to.change.their.political.opinion." =
                          "convinceSomeone",
                        "polBehavior....contacted.a.politician..or.a.government.official." =
                          "contactedPolitician",
                        "polBehavior....worked.in.a.political.party.or.action.group." =
                          "workedParty",
                        "polBehavior....worn.or.displayed.a.political.badge..sticker..or.sign." =
                          "wornSticker",
                        "polBehavior....signed.a.petition." =
                          "signedPetition",
                        "polBehavior....taken.part.in.a.lawful.public.demonstration." =
                          "demonstration",
                        "polBehavior....boycotted.certain.products." =
                          "boycott",
                        "polBehavior....collected.signatures.for.a.petition." =
                          "collectedSignatures",
                        "groups.A.group.related.to.your..strong.job..strong...like.a.union..business..or.professional.organization" =
                          "groupsJob",
                        "groups.A.group.related.to.your..strong.religious.beliefs..strong...like.a.church..mosque..synagogue..or.other.religious.organization" =
                          "groupReligion",
                        "groups.A.group.related.to.your..strong.hobbies..strong...strong....strong.like.a.sports..leisure..or.cultural.group" =
                          "groupHobbies",
                        "groups.A.group.related.to.a..strong.social.or.political.cause..strong...such.as.a.voluntary.organization.or.political.party" =
                          "groupPolitical",
                        "groups.Another.voluntary.organization" =
                          "groupOther",
                        "groupMembers.A.group.related.to.your..strong.job..strong...like.a.union..business..or.professional.organization" =
                          "membersJob",
                        "groupMembers.A.group.related.to.your..strong.religious.beliefs..strong...like.a.church..mosque..synagogue..or.other.religious.organization" =
                          "membersReligion",
                        "groupMembers.A.group.related.to.your..strong.hobbies..strong...strong....strong.like.a.sports..leisure..or.cultural.group" =
                          "membersHobbies",
                        "groupMembers.A.group.related.to.a..strong.social.or.political.cause..strong...such.as.a.voluntary.organization.or.political.party" =
                          "membersPolitical",
                        "groupMembers.Another.voluntary.organization" =
                          "membersOther"
                      ))



# Review psychological integration ----------------------------------------

# As defined in the Qualtrics surevey, all answers in psychological integration
# are already coded the right way. To check for missings, table all variables:

print(lapply(df[, c("connectionHc", "outsider", "futureHc", "isolation")], 
             table, useNA = "ifany"))

# You can now create and rescale the psychological integration index
df$psy24 <- df$connectionHc + df$futureHc + df$isolation + df$outsider
df$psy24s <- rescale(df$psy24, to = c(0, 1), from = c(4, 20))

df$psy12 <- df$connectionHc + df$outsider 
df$psy12s <- rescale(df$psy12, to = c(0, 1), from = c(2, 10))


# Review navigational integration -----------------------------------------

# The first three items are already coded the right way and can be inspected:

print(lapply(df[, c("seeDoctor", "searchJob", "legalHelp")], 
             table, useNA = "ifany"))

# The quiz questions need to be recoded and aggregated
df$dui <- ifelse(df$dui == 2, 1, 0)

df$taxes <- ifelse(df$taxes == 4, 1, 0)

df$address <- ifelse(df$address == 2, 1, 0)

df$medHelp <- ifelse(df$medHelp == 3, 1, 0)

df$navQuiz <- df$dui + df$taxes + df$address + df$medHelp + 1

table(df$navQuiz, useNA= "ifany")

# You can now create and rescale the navigational integration index
df$nav24 <- df$seeDoctor + df$searchJob + df$legalHelp + df$navQuiz
df$nav24s <- rescale(df$nav24, to = c(0, 1), from = c(4, 20))

df$nav12 <- df$seeDoctor + df$searchJob
df$nav12s <- rescale(df$nav12, to = c(0, 1), from = c(2, 10))


# Review economic integration ---------------------------------------------

# In this section, we need the respondents' household size. First we need to 
# check if any respondent is form a household of more then 15 members. If this
# is the case the answer needs to be recoded.

# Household
table(df$hhsize, useNA = "ifany")

if (sum(df$hhsize == 99, na.rm = TRUE) != 0) {
  stop("There are households with more than 15 members. The variable needs recoding")
} else {
  print("All households have 15 or fewer members. No recoding neccessary")
}

# In this example, households of more than 15 members are assigned a random
# value between 16 and 20.
df$hhsize[df$hhsize == 99] <- sample(16:20, sum(df$hhsize == 99), replace = TRUE)


# If a respondent doesn't answer the income question, we use 'unfolding' 
# questions to narrow down that respondent's income. These questions need to
# be recoded to the middle value of the estimated income interval.  

# Recode unfolding answers
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 0 & df$up1stQ == 0)] <- 15000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 0 & df$up1stQ == 1)] <- 35000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 1 & df$up4thQ == 1)] <- 165000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 1 & df$up4thQ == 0 & df$up3rdQ == 0)] <- 60000
df$hhInc[which(is.na(df$hhInc) &
                 df$up2ndQ == 1 & df$up4thQ == 0 & df$up3rdQ == 1)] <- 90000


# Now recode all other values to the middle of the category, 
# for the first cat I use $1000 per month, 
# for highest I add the interval of 9 to highets.
df$hhInc[df$hhInc == 1] <- 12000
df$hhInc[df$hhInc == 2] <- 20000
df$hhInc[df$hhInc == 3] <- 30000
df$hhInc[df$hhInc == 4] <- 40000
df$hhInc[df$hhInc == 5] <- 52500
df$hhInc[df$hhInc == 6] <- 67500
df$hhInc[df$hhInc == 7] <- 82500
df$hhInc[df$hhInc == 8] <- 105000
df$hhInc[df$hhInc == 9] <- 142500
df$hhInc[df$hhInc == 10] <- 210000

# Check if there are still NAs
table(df$hhInc, useNA = "ifany")

## Divide recoded hhInc by sqrt of hhsize
df$equHhInc <- df$hhInc / sqrt(df$hhsize)

# Based on  weighted ACS data (2014), I estimate the median US equivalised 
# household income with to be $42,900 

gmeh <- 42900

# I then make 5 categories
df$income <- NA
df$income[which(df$equHhInc < (gmeh/3))] <- 1
df$income[which(df$equHhInc > (gmeh/3) &
                  df$equHhInc < (gmeh/1.5))] <- 2
df$income[which(df$equHhInc >(gmeh/1.5) & df$equHhInc < gmeh)] <- 3
df$income[which(df$equHhInc > gmeh & df$equHhInc < (gmeh + (gmeh/3)))] <- 4
df$income[which(df$equHhInc > (gmeh + (gmeh/3)))] <- 5


table(df$income, useNA = "ifany")


# Employment, ther is an open text field. Check if open answers need manual recoding
table(df$workStatus, useNA = "ifany")

{
  if (sum(df$workStatus[grep("[[:alnum:]]", df$workStatus.TEXT)] == 10) != 0)
  {
    stop("There are text values in workStatus that have not been recoded")
  }
  
  print("All text values in workStatus have been recoded")
}

# Recode employment according to ACS categories

df$employment <- ifelse(df$workStatus == 1 |
                              df$workStatus == 7,
                            5,
                            ifelse(df$workStatus == 2 |
                                     df$workStatus == 5 |
                                     df$workStatus == 6 |
                                     df$workStatus == 8 |
                                     df$workStatus == 9 |
                                     df$workStatus == 10,
                                   3,
                                   ifelse(df$workStatus == 3 |
                                            df$workStatus == 4,
                                          1,
                                          NA)))

table(df$employment, useNA = "ifany")

# Expenses: Here the answers to the four items need to be aggregated
df$expenses <-
  df$expenses..500 + df$expenses..1.000 +
  df$expenses..10.000 +  df$expenses..50.000 + 1
table(df$expenses, useNA = "ifany")

# Employment satisfaction is already coded the right way. 
table(df$emplSatisfied, useNA = "ifany")

# You can now create and rescale the economic integration index
df$econ24 <- df$income + df$employment + df$expenses + df$emplSatisfied
df$econ24s <- rescale(df$econ24, to = c(0, 1), from = c(4, 20))

df$econ12 <- df$income + df$employment
df$econ12s <- rescale(df$econ12, to = c(0, 1), from = c(2, 10))


# Review social integration ----------------------------------------------

# The dinner, contact, and the favors question are already coded the right
# way:

print(lapply(df[, c("dinner", "contactsInUs", "favors")], 
             table, useNA = "ifany"))

# The question on group membership needs recoding

# There can be inconsistencies in the data. Some respondents that first say
# that they participate in a given organization can later claim not to. 

# Recode (and rename) in a way that if a respondent answered "do not belong" in 
# one question, it is coded like that in the other as well

## Unions
df$groupsJob[df$membersJob == 0] <- 1
df$membersJob[df$groupsJob == 1] <- 0
df$membersJob[is.na(df$membersJob)] <- 0

## Religion
df$groupsReligion[df$membersReligion == 0] <- 1
df$membersReligion[df$groupsReligion == 1] <- 0
df$membersReligion[is.na(df$membersReligion)] <- 0

## Hobbies
df$groupsHobbies[df$membersHobbies == 0] <- 1
df$membersHobbies[df$groupsHobbies == 1] <- 0
df$membersHobbies[is.na(df$membersHobbies)] <- 0

## Political/Social
df$groupsPolitical[df$membersPolitical == 0] <- 1
df$membersPolitical[df$groupsPolitical == 1] <- 0
df$membersPolitical[is.na(df$membersPolitical)] <- 0

## Other
df$groupsOther[df$membersOther == 0] <- 1
df$membersOther[df$groupsOther == 1] <- 0
df$membersOther[is.na(df$membersOther)] <- 0


## Code highest participation * natives value
df$maxOrg <-  apply(data.frame(job = (df$groupsJob * df$membersJob), 
                               religion = (df$groupReligion * df$membersReligion), 
                               hobbies = (df$groupHobbies * df$membersHobbies),
                               political = (df$groupPolitical * df$membersPolitical),
                               other = (df$groupOther * df$membersOther)), 1, max)

# Rescale
df$maxOrg <- ceiling(scales::rescale(df$maxOrg, to = c(1,5), from = c(0, 25)))

# You can now create and rescale the social integration index
df$soc24 <- df$maxOrg + df$favors + df$dinner + df$contactsInUs
df$soc24s <- rescale(df$soc24, to = c(0, 1), from = c(4, 20))

df$soc12 <- df$dinner + df$contactsInUs
df$soc12s <- rescale(df$soc12, to = c(0, 1), from = c(2, 10))


# Review political integration --------------------------------------------

# The questions on political discussions and political understanding are
# already coded in the right direction and can be inspected

print(lapply(df[, c("polUnderstanding",
                    "polDiscuss")], table, useNA = "ifany"))

# The quiz needs recoding

## The left-right question needs to be recoded depending on which statement was
## shown. 

df$lrQuiz <- NA
df$lrQuiz <-
  ifelse((df$rightLeftOfLeft == 0 &
            is.na(df$rightRightOfRight)) |
           (df$rightRightOfRight == 1 & is.na(df$rightLeftOfLeft)),
         1,
         0)
# The rest of the quiz needs to be recoded as well
df$president <- ifelse(df$president == 1, 1, 0)

df$largestParty <- ifelse(df$largestParty == 1, 1, 0)

df$ageElection <- ifelse(df$ageElection == 4, 1, 0)

df$polQuiz <-
  df$lrQuiz + df$president + df$largestParty + df$ageElection + 1

# Aggregate and recode all political action items
df$polSum <-
  rowSums(df[, c(
    "influenceVote",
    "publicStatement",
    "publicDiscussion",
    "convinceSomeone",
    "contactedPolitician",
    "workedParty",
    "wornSticker",
    "signedPetition",
    "demonstration",
    "collectedSignatures",
    "boycott"
  )], na.rm = FALSE)

df$polAction[df$polSum == 0] <- 1
df$polAction[df$polSum == 1] <- 2
df$polAction[df$polSum == 2] <- 3
df$polAction[df$polSum == 3] <- 4
df$polAction[df$polSum == 4] <- 4
df$polAction[df$polSum >= 5] <- 5

# Look at all questions
print(lapply(df[, c("polUnderstanding",
                    "polDiscuss",
                    "polQuiz",
                    "polAction")], table, useNA = "ifany"))

# You can now create and rescale the political integration index
df$pol24 <- df$polUnderstanding + df$polDiscuss + df$polQuiz + df$polAction
df$pol24s <- rescale(df$pol24, to = c(0, 1), from = c(4, 20))

df$pol12 <- df$polUnderstanding + df$polDiscuss 
df$pol12s <- rescale(df$pol12, to = c(0, 1), from = c(2, 10))


# Review linguistic integration -------------------------------------------

# All questions are already coded the right way
lapply(df[, c("read", "speak", "write", "listen")], table, useNA = "ifany")

# You can now create and rescale the linguistic integration index
df$ling24 <- df$read + df$speak + df$write + df$listen
df$ling24s <- rescale(df$ling24, to = c(0, 1), from = c(4, 20))

df$ling12 <- df$read + df$speak 
df$ling12s <- rescale(df$ling12, to = c(0, 1), from = c(2, 10))


# Create IPL-24 and 12 -----------------------------------------------------------

df$ipl24 <- df$pol24 + df$econ24 + df$soc24 + df$psy24 + df$ling24 + df$nav24
df$ipl24s <- rescale(df$ipl24, to = c(0, 1), from = c(24, 120))

df$ipl12 <- df$pol12 + df$econ12 + df$soc12 + df$psy12 + df$ling12 + df$nav12
df$ipl12s <- rescale(df$ipl12, to = c(0, 1), from = c(12, 60))





